# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/logging/v2/logging.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import monitored_resource_pb2 as google_dot_api_dot_monitored__resource__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.logging.v2 import log_entry_pb2 as google_dot_logging_dot_v2_dot_log__entry__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fgoogle/logging/v2/logging.proto\x12\x11google.logging.v2\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/client.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a#google/api/monitored_resource.proto\x1a\x19google/api/resource.proto\x1a!google/logging/v2/log_entry.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x17google/rpc/status.proto\"H\n\x10\x44\x65leteLogRequest\x12\x34\n\x08log_name\x18\x01 \x01(\tB\"\xe0\x41\x02\xfa\x41\x1c\n\x1alogging.googleapis.com/Log\"\xe6\x02\n\x16WriteLogEntriesRequest\x12\x34\n\x08log_name\x18\x01 \x01(\tB\"\xe0\x41\x01\xfa\x41\x1c\n\x1alogging.googleapis.com/Log\x12\x34\n\x08resource\x18\x02 \x01(\x0b\x32\x1d.google.api.MonitoredResourceB\x03\xe0\x41\x01\x12J\n\x06labels\x18\x03 \x03(\x0b\x32\x35.google.logging.v2.WriteLogEntriesRequest.LabelsEntryB\x03\xe0\x41\x01\x12\x31\n\x07\x65ntries\x18\x04 \x03(\x0b\x32\x1b.google.logging.v2.LogEntryB\x03\xe0\x41\x02\x12\x1c\n\x0fpartial_success\x18\x05 \x01(\x08\x42\x03\xe0\x41\x01\x12\x14\n\x07\x64ry_run\x18\x06 \x01(\x08\x42\x03\xe0\x41\x01\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x19\n\x17WriteLogEntriesResponse\"\xc8\x01\n\x1cWriteLogEntriesPartialErrors\x12]\n\x10log_entry_errors\x18\x01 \x03(\x0b\x32\x43.google.logging.v2.WriteLogEntriesPartialErrors.LogEntryErrorsEntry\x1aI\n\x13LogEntryErrorsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12!\n\x05value\x18\x02 \x01(\x0b\x32\x12.google.rpc.Status:\x02\x38\x01\"\xb0\x01\n\x15ListLogEntriesRequest\x12:\n\x0eresource_names\x18\x08 \x03(\tB\"\xe0\x41\x02\xfa\x41\x1c\x12\x1alogging.googleapis.com/Log\x12\x13\n\x06\x66ilter\x18\x02 \x01(\tB\x03\xe0\x41\x01\x12\x15\n\x08order_by\x18\x03 \x01(\tB\x03\xe0\x41\x01\x12\x16\n\tpage_size\x18\x04 \x01(\x05\x42\x03\xe0\x41\x01\x12\x17\n\npage_token\x18\x05 \x01(\tB\x03\xe0\x41\x01\"_\n\x16ListLogEntriesResponse\x12,\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x1b.google.logging.v2.LogEntry\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"Z\n\'ListMonitoredResourceDescriptorsRequest\x12\x16\n\tpage_size\x18\x01 \x01(\x05\x42\x03\xe0\x41\x01\x12\x17\n\npage_token\x18\x02 \x01(\tB\x03\xe0\x41\x01\"\x8a\x01\n(ListMonitoredResourceDescriptorsResponse\x12\x45\n\x14resource_descriptors\x18\x01 \x03(\x0b\x32\'.google.api.MonitoredResourceDescriptor\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xb2\x01\n\x0fListLogsRequest\x12\x32\n\x06parent\x18\x01 \x01(\tB\"\xe0\x41\x02\xfa\x41\x1c\x12\x1alogging.googleapis.com/Log\x12:\n\x0eresource_names\x18\x08 \x03(\tB\"\xe0\x41\x01\xfa\x41\x1c\x12\x1alogging.googleapis.com/Log\x12\x16\n\tpage_size\x18\x02 \x01(\x05\x42\x03\xe0\x41\x01\x12\x17\n\npage_token\x18\x03 \x01(\tB\x03\xe0\x41\x01\">\n\x10ListLogsResponse\x12\x11\n\tlog_names\x18\x03 \x03(\t\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x80\x01\n\x15TailLogEntriesRequest\x12\x1b\n\x0eresource_names\x18\x01 \x03(\tB\x03\xe0\x41\x02\x12\x13\n\x06\x66ilter\x18\x02 \x01(\tB\x03\xe0\x41\x01\x12\x35\n\rbuffer_window\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\x03\xe0\x41\x01\"\xdf\x02\n\x16TailLogEntriesResponse\x12,\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x1b.google.logging.v2.LogEntry\x12S\n\x10suppression_info\x18\x02 \x03(\x0b\x32\x39.google.logging.v2.TailLogEntriesResponse.SuppressionInfo\x1a\xc1\x01\n\x0fSuppressionInfo\x12P\n\x06reason\x18\x01 \x01(\x0e\x32@.google.logging.v2.TailLogEntriesResponse.SuppressionInfo.Reason\x12\x18\n\x10suppressed_count\x18\x02 \x01(\x05\"B\n\x06Reason\x12\x16\n\x12REASON_UNSPECIFIED\x10\x00\x12\x0e\n\nRATE_LIMIT\x10\x01\x12\x10\n\x0cNOT_CONSUMED\x10\x02\x32\xe9\r\n\x10LoggingServiceV2\x12\x93\x02\n\tDeleteLog\x12#.google.logging.v2.DeleteLogRequest\x1a\x16.google.protobuf.Empty\"\xc8\x01\xda\x41\x08log_name\x82\xd3\xe4\x93\x02\xb6\x01* /v2/{log_name=projects/*/logs/*}Z\x1b*\x19/v2/{log_name=*/*/logs/*}Z\'*%/v2/{log_name=organizations/*/logs/*}Z!*\x1f/v2/{log_name=folders/*/logs/*}Z)*\'/v2/{log_name=billingAccounts/*/logs/*}\x12\xa9\x01\n\x0fWriteLogEntries\x12).google.logging.v2.WriteLogEntriesRequest\x1a*.google.logging.v2.WriteLogEntriesResponse\"?\xda\x41 log_name,resource,labels,entries\x82\xd3\xe4\x93\x02\x16\"\x11/v2/entries:write:\x01*\x12\xa3\x01\n\x0eListLogEntries\x12(.google.logging.v2.ListLogEntriesRequest\x1a).google.logging.v2.ListLogEntriesResponse\"<\xda\x41\x1eresource_names,filter,order_by\x82\xd3\xe4\x93\x02\x15\"\x10/v2/entries:list:\x01*\x12\xc5\x01\n ListMonitoredResourceDescriptors\x12:.google.logging.v2.ListMonitoredResourceDescriptorsRequest\x1a;.google.logging.v2.ListMonitoredResourceDescriptorsResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /v2/monitoredResourceDescriptors\x12\x8b\x04\n\x08ListLogs\x12\".google.logging.v2.ListLogsRequest\x1a#.google.logging.v2.ListLogsResponse\"\xb5\x03\xda\x41\x06parent\x82\xd3\xe4\x93\x02\xa5\x03\x12\x15/v2/{parent=*/*}/logsZ\x1e\x12\x1c/v2/{parent=projects/*}/logsZ#\x12!/v2/{parent=organizations/*}/logsZ\x1d\x12\x1b/v2/{parent=folders/*}/logsZ%\x12#/v2/{parent=billingAccounts/*}/logsZ<\x12:/v2/{parent=projects/*/locations/*/buckets/*/views/*}/logsZA\x12?/v2/{parent=organizations/*/locations/*/buckets/*/views/*}/logsZ;\x12\x39/v2/{parent=folders/*/locations/*/buckets/*/views/*}/logsZC\x12\x41/v2/{parent=billingAccounts/*/locations/*/buckets/*/views/*}/logs\x12\x86\x01\n\x0eTailLogEntries\x12(.google.logging.v2.TailLogEntriesRequest\x1a).google.logging.v2.TailLogEntriesResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\"\x10/v2/entries:tail:\x01*(\x01\x30\x01\x1a\x8d\x02\xca\x41\x16logging.googleapis.com\xd2\x41\xf0\x01https://www.googleapis.com/auth/cloud-platform,https://www.googleapis.com/auth/cloud-platform.read-only,https://www.googleapis.com/auth/logging.admin,https://www.googleapis.com/auth/logging.read,https://www.googleapis.com/auth/logging.writeB\xb2\x01\n\x15\x63om.google.logging.v2B\x0cLoggingProtoP\x01Z5cloud.google.com/go/logging/apiv2/loggingpb;loggingpb\xf8\x01\x01\xaa\x02\x17Google.Cloud.Logging.V2\xca\x02\x17Google\\Cloud\\Logging\\V2\xea\x02\x1aGoogle::Cloud::Logging::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.logging.v2.logging_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\025com.google.logging.v2B\014LoggingProtoP\001Z5cloud.google.com/go/logging/apiv2/loggingpb;loggingpb\370\001\001\252\002\027Google.Cloud.Logging.V2\312\002\027Google\\Cloud\\Logging\\V2\352\002\032Google::Cloud::Logging::V2'
  _DELETELOGREQUEST.fields_by_name['log_name']._options = None
  _DELETELOGREQUEST.fields_by_name['log_name']._serialized_options = b'\340A\002\372A\034\n\032logging.googleapis.com/Log'
  _WRITELOGENTRIESREQUEST_LABELSENTRY._options = None
  _WRITELOGENTRIESREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _WRITELOGENTRIESREQUEST.fields_by_name['log_name']._options = None
  _WRITELOGENTRIESREQUEST.fields_by_name['log_name']._serialized_options = b'\340A\001\372A\034\n\032logging.googleapis.com/Log'
  _WRITELOGENTRIESREQUEST.fields_by_name['resource']._options = None
  _WRITELOGENTRIESREQUEST.fields_by_name['resource']._serialized_options = b'\340A\001'
  _WRITELOGENTRIESREQUEST.fields_by_name['labels']._options = None
  _WRITELOGENTRIESREQUEST.fields_by_name['labels']._serialized_options = b'\340A\001'
  _WRITELOGENTRIESREQUEST.fields_by_name['entries']._options = None
  _WRITELOGENTRIESREQUEST.fields_by_name['entries']._serialized_options = b'\340A\002'
  _WRITELOGENTRIESREQUEST.fields_by_name['partial_success']._options = None
  _WRITELOGENTRIESREQUEST.fields_by_name['partial_success']._serialized_options = b'\340A\001'
  _WRITELOGENTRIESREQUEST.fields_by_name['dry_run']._options = None
  _WRITELOGENTRIESREQUEST.fields_by_name['dry_run']._serialized_options = b'\340A\001'
  _WRITELOGENTRIESPARTIALERRORS_LOGENTRYERRORSENTRY._options = None
  _WRITELOGENTRIESPARTIALERRORS_LOGENTRYERRORSENTRY._serialized_options = b'8\001'
  _LISTLOGENTRIESREQUEST.fields_by_name['resource_names']._options = None
  _LISTLOGENTRIESREQUEST.fields_by_name['resource_names']._serialized_options = b'\340A\002\372A\034\022\032logging.googleapis.com/Log'
  _LISTLOGENTRIESREQUEST.fields_by_name['filter']._options = None
  _LISTLOGENTRIESREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _LISTLOGENTRIESREQUEST.fields_by_name['order_by']._options = None
  _LISTLOGENTRIESREQUEST.fields_by_name['order_by']._serialized_options = b'\340A\001'
  _LISTLOGENTRIESREQUEST.fields_by_name['page_size']._options = None
  _LISTLOGENTRIESREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTLOGENTRIESREQUEST.fields_by_name['page_token']._options = None
  _LISTLOGENTRIESREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\001'
  _LISTMONITOREDRESOURCEDESCRIPTORSREQUEST.fields_by_name['page_size']._options = None
  _LISTMONITOREDRESOURCEDESCRIPTORSREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTMONITOREDRESOURCEDESCRIPTORSREQUEST.fields_by_name['page_token']._options = None
  _LISTMONITOREDRESOURCEDESCRIPTORSREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\001'
  _LISTLOGSREQUEST.fields_by_name['parent']._options = None
  _LISTLOGSREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002\372A\034\022\032logging.googleapis.com/Log'
  _LISTLOGSREQUEST.fields_by_name['resource_names']._options = None
  _LISTLOGSREQUEST.fields_by_name['resource_names']._serialized_options = b'\340A\001\372A\034\022\032logging.googleapis.com/Log'
  _LISTLOGSREQUEST.fields_by_name['page_size']._options = None
  _LISTLOGSREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTLOGSREQUEST.fields_by_name['page_token']._options = None
  _LISTLOGSREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\001'
  _TAILLOGENTRIESREQUEST.fields_by_name['resource_names']._options = None
  _TAILLOGENTRIESREQUEST.fields_by_name['resource_names']._serialized_options = b'\340A\002'
  _TAILLOGENTRIESREQUEST.fields_by_name['filter']._options = None
  _TAILLOGENTRIESREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _TAILLOGENTRIESREQUEST.fields_by_name['buffer_window']._options = None
  _TAILLOGENTRIESREQUEST.fields_by_name['buffer_window']._serialized_options = b'\340A\001'
  _LOGGINGSERVICEV2._options = None
  _LOGGINGSERVICEV2._serialized_options = b'\312A\026logging.googleapis.com\322A\360\001https://www.googleapis.com/auth/cloud-platform,https://www.googleapis.com/auth/cloud-platform.read-only,https://www.googleapis.com/auth/logging.admin,https://www.googleapis.com/auth/logging.read,https://www.googleapis.com/auth/logging.write'
  _LOGGINGSERVICEV2.methods_by_name['DeleteLog']._options = None
  _LOGGINGSERVICEV2.methods_by_name['DeleteLog']._serialized_options = b'\332A\010log_name\202\323\344\223\002\266\001* /v2/{log_name=projects/*/logs/*}Z\033*\031/v2/{log_name=*/*/logs/*}Z\'*%/v2/{log_name=organizations/*/logs/*}Z!*\037/v2/{log_name=folders/*/logs/*}Z)*\'/v2/{log_name=billingAccounts/*/logs/*}'
  _LOGGINGSERVICEV2.methods_by_name['WriteLogEntries']._options = None
  _LOGGINGSERVICEV2.methods_by_name['WriteLogEntries']._serialized_options = b'\332A log_name,resource,labels,entries\202\323\344\223\002\026\"\021/v2/entries:write:\001*'
  _LOGGINGSERVICEV2.methods_by_name['ListLogEntries']._options = None
  _LOGGINGSERVICEV2.methods_by_name['ListLogEntries']._serialized_options = b'\332A\036resource_names,filter,order_by\202\323\344\223\002\025\"\020/v2/entries:list:\001*'
  _LOGGINGSERVICEV2.methods_by_name['ListMonitoredResourceDescriptors']._options = None
  _LOGGINGSERVICEV2.methods_by_name['ListMonitoredResourceDescriptors']._serialized_options = b'\202\323\344\223\002\"\022 /v2/monitoredResourceDescriptors'
  _LOGGINGSERVICEV2.methods_by_name['ListLogs']._options = None
  _LOGGINGSERVICEV2.methods_by_name['ListLogs']._serialized_options = b'\332A\006parent\202\323\344\223\002\245\003\022\025/v2/{parent=*/*}/logsZ\036\022\034/v2/{parent=projects/*}/logsZ#\022!/v2/{parent=organizations/*}/logsZ\035\022\033/v2/{parent=folders/*}/logsZ%\022#/v2/{parent=billingAccounts/*}/logsZ<\022:/v2/{parent=projects/*/locations/*/buckets/*/views/*}/logsZA\022?/v2/{parent=organizations/*/locations/*/buckets/*/views/*}/logsZ;\0229/v2/{parent=folders/*/locations/*/buckets/*/views/*}/logsZC\022A/v2/{parent=billingAccounts/*/locations/*/buckets/*/views/*}/logs'
  _LOGGINGSERVICEV2.methods_by_name['TailLogEntries']._options = None
  _LOGGINGSERVICEV2.methods_by_name['TailLogEntries']._serialized_options = b'\202\323\344\223\002\025\"\020/v2/entries:tail:\001*'
  _globals['_DELETELOGREQUEST']._serialized_start=327
  _globals['_DELETELOGREQUEST']._serialized_end=399
  _globals['_WRITELOGENTRIESREQUEST']._serialized_start=402
  _globals['_WRITELOGENTRIESREQUEST']._serialized_end=760
  _globals['_WRITELOGENTRIESREQUEST_LABELSENTRY']._serialized_start=715
  _globals['_WRITELOGENTRIESREQUEST_LABELSENTRY']._serialized_end=760
  _globals['_WRITELOGENTRIESRESPONSE']._serialized_start=762
  _globals['_WRITELOGENTRIESRESPONSE']._serialized_end=787
  _globals['_WRITELOGENTRIESPARTIALERRORS']._serialized_start=790
  _globals['_WRITELOGENTRIESPARTIALERRORS']._serialized_end=990
  _globals['_WRITELOGENTRIESPARTIALERRORS_LOGENTRYERRORSENTRY']._serialized_start=917
  _globals['_WRITELOGENTRIESPARTIALERRORS_LOGENTRYERRORSENTRY']._serialized_end=990
  _globals['_LISTLOGENTRIESREQUEST']._serialized_start=993
  _globals['_LISTLOGENTRIESREQUEST']._serialized_end=1169
  _globals['_LISTLOGENTRIESRESPONSE']._serialized_start=1171
  _globals['_LISTLOGENTRIESRESPONSE']._serialized_end=1266
  _globals['_LISTMONITOREDRESOURCEDESCRIPTORSREQUEST']._serialized_start=1268
  _globals['_LISTMONITOREDRESOURCEDESCRIPTORSREQUEST']._serialized_end=1358
  _globals['_LISTMONITOREDRESOURCEDESCRIPTORSRESPONSE']._serialized_start=1361
  _globals['_LISTMONITOREDRESOURCEDESCRIPTORSRESPONSE']._serialized_end=1499
  _globals['_LISTLOGSREQUEST']._serialized_start=1502
  _globals['_LISTLOGSREQUEST']._serialized_end=1680
  _globals['_LISTLOGSRESPONSE']._serialized_start=1682
  _globals['_LISTLOGSRESPONSE']._serialized_end=1744
  _globals['_TAILLOGENTRIESREQUEST']._serialized_start=1747
  _globals['_TAILLOGENTRIESREQUEST']._serialized_end=1875
  _globals['_TAILLOGENTRIESRESPONSE']._serialized_start=1878
  _globals['_TAILLOGENTRIESRESPONSE']._serialized_end=2229
  _globals['_TAILLOGENTRIESRESPONSE_SUPPRESSIONINFO']._serialized_start=2036
  _globals['_TAILLOGENTRIESRESPONSE_SUPPRESSIONINFO']._serialized_end=2229
  _globals['_TAILLOGENTRIESRESPONSE_SUPPRESSIONINFO_REASON']._serialized_start=2163
  _globals['_TAILLOGENTRIESRESPONSE_SUPPRESSIONINFO_REASON']._serialized_end=2229
  _globals['_LOGGINGSERVICEV2']._serialized_start=2232
  _globals['_LOGGINGSERVICEV2']._serialized_end=4001
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/filter/http/health_check/v2/health_check.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.route import route_components_pb2 as envoy_dot_api_dot_v2_dot_route_dot_route__components__pb2
from envoy.type import percent_pb2 as envoy_dot_type_dot_percent__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;envoy/config/filter/http/health_check/v2/health_check.proto\x12(envoy.config.filter.http.health_check.v2\x1a)envoy/api/v2/route/route_components.proto\x1a\x18\x65nvoy/type/percent.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x94\x03\n\x0bHealthCheck\x12?\n\x11pass_through_mode\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12-\n\ncache_time\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x80\x01\n\x1f\x63luster_min_healthy_percentages\x18\x04 \x03(\x0b\x32W.envoy.config.filter.http.health_check.v2.HealthCheck.ClusterMinHealthyPercentagesEntry\x12\x32\n\x07headers\x18\x05 \x03(\x0b\x32!.envoy.api.v2.route.HeaderMatcher\x1aX\n!ClusterMinHealthyPercentagesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\"\n\x05value\x18\x02 \x01(\x0b\x32\x13.envoy.type.Percent:\x02\x38\x01J\x04\x08\x02\x10\x03\x42\xe9\x01\n6io.envoyproxy.envoy.config.filter.http.health_check.v2B\x10HealthCheckProtoP\x01Z^github.com/envoyproxy/go-control-plane/envoy/config/filter/http/health_check/v2;health_checkv2\xf2\x98\xfe\x8f\x05/\x12-envoy.extensions.filters.http.health_check.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.filter.http.health_check.v2.health_check_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n6io.envoyproxy.envoy.config.filter.http.health_check.v2B\020HealthCheckProtoP\001Z^github.com/envoyproxy/go-control-plane/envoy/config/filter/http/health_check/v2;health_checkv2\362\230\376\217\005/\022-envoy.extensions.filters.http.health_check.v3\272\200\310\321\006\002\020\001'
  _HEALTHCHECK_CLUSTERMINHEALTHYPERCENTAGESENTRY._options = None
  _HEALTHCHECK_CLUSTERMINHEALTHYPERCENTAGESENTRY._serialized_options = b'8\001'
  _HEALTHCHECK.fields_by_name['pass_through_mode']._options = None
  _HEALTHCHECK.fields_by_name['pass_through_mode']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_HEALTHCHECK']._serialized_start=327
  _globals['_HEALTHCHECK']._serialized_end=731
  _globals['_HEALTHCHECK_CLUSTERMINHEALTHYPERCENTAGESENTRY']._serialized_start=637
  _globals['_HEALTHCHECK_CLUSTERMINHEALTHYPERCENTAGESENTRY']._serialized_end=725
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: xds/core/v3/resource_locator.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from xds.annotations.v3 import status_pb2 as xds_dot_annotations_dot_v3_dot_status__pb2
from xds.core.v3 import context_params_pb2 as xds_dot_core_dot_v3_dot_context__params__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"xds/core/v3/resource_locator.proto\x12\x0bxds.core.v3\x1a\x1fxds/annotations/v3/status.proto\x1a xds/core/v3/context_params.proto\x1a\x17validate/validate.proto\"\xc2\x03\n\x0fResourceLocator\x12=\n\x06scheme\x18\x01 \x01(\x0e\x32#.xds.core.v3.ResourceLocator.SchemeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\n\n\x02id\x18\x02 \x01(\t\x12\x11\n\tauthority\x18\x03 \x01(\t\x12\x1e\n\rresource_type\x18\x04 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x33\n\rexact_context\x18\x05 \x01(\x0b\x32\x1a.xds.core.v3.ContextParamsH\x00\x12:\n\ndirectives\x18\x06 \x03(\x0b\x32&.xds.core.v3.ResourceLocator.Directive\x1a|\n\tDirective\x12+\n\x03\x61lt\x18\x01 \x01(\x0b\x32\x1c.xds.core.v3.ResourceLocatorH\x00\x12\x30\n\x05\x65ntry\x18\x02 \x01(\tB\x1f\xfa\x42\x1cr\x1a\x10\x01\x32\x16^[0-9a-zA-Z_\\-\\./~:]+$H\x00\x42\x10\n\tdirective\x12\x03\xf8\x42\x01\"\'\n\x06Scheme\x12\t\n\x05XDSTP\x10\x00\x12\x08\n\x04HTTP\x10\x01\x12\x08\n\x04\x46ILE\x10\x02\x42\x19\n\x17\x63ontext_param_specifierB\\\n\x16\x63om.github.xds.core.v3B\x14ResourceLocatorProtoP\x01Z\"github.com/cncf/xds/go/xds/core/v3\xd2\xc6\xa4\xe1\x06\x02\x08\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xds.core.v3.resource_locator_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026com.github.xds.core.v3B\024ResourceLocatorProtoP\001Z\"github.com/cncf/xds/go/xds/core/v3\322\306\244\341\006\002\010\001'
  _RESOURCELOCATOR_DIRECTIVE.oneofs_by_name['directive']._options = None
  _RESOURCELOCATOR_DIRECTIVE.oneofs_by_name['directive']._serialized_options = b'\370B\001'
  _RESOURCELOCATOR_DIRECTIVE.fields_by_name['entry']._options = None
  _RESOURCELOCATOR_DIRECTIVE.fields_by_name['entry']._serialized_options = b'\372B\034r\032\020\0012\026^[0-9a-zA-Z_\\-\\./~:]+$'
  _RESOURCELOCATOR.fields_by_name['scheme']._options = None
  _RESOURCELOCATOR.fields_by_name['scheme']._serialized_options = b'\372B\005\202\001\002\020\001'
  _RESOURCELOCATOR.fields_by_name['resource_type']._options = None
  _RESOURCELOCATOR.fields_by_name['resource_type']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_RESOURCELOCATOR']._serialized_start=144
  _globals['_RESOURCELOCATOR']._serialized_end=594
  _globals['_RESOURCELOCATOR_DIRECTIVE']._serialized_start=402
  _globals['_RESOURCELOCATOR_DIRECTIVE']._serialized_end=526
  _globals['_RESOURCELOCATOR_SCHEME']._serialized_start=528
  _globals['_RESOURCELOCATOR_SCHEME']._serialized_end=567
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/http/injected_credentials/oauth2/v3/oauth2.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import http_uri_pb2 as envoy_dot_config_dot_core_dot_v3_dot_http__uri__pb2
from envoy.extensions.transport_sockets.tls.v3 import secret_pb2 as envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v3_dot_secret__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from xds.annotations.v3 import status_pb2 as xds_dot_annotations_dot_v3_dot_status__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAenvoy/extensions/http/injected_credentials/oauth2/v3/oauth2.proto\x12\x34\x65nvoy.extensions.http.injected_credentials.oauth2.v3\x1a#envoy/config/core/v3/http_uri.proto\x1a\x36\x65nvoy/extensions/transport_sockets/tls/v3/secret.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fxds/annotations/v3/status.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xbf\x04\n\x06OAuth2\x12?\n\x0etoken_endpoint\x18\x01 \x01(\x0b\x32\x1d.envoy.config.core.v3.HttpUriB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x0e\n\x06scopes\x18\x02 \x03(\t\x12l\n\x12\x63lient_credentials\x18\x03 \x01(\x0b\x32N.envoy.extensions.http.injected_credentials.oauth2.v3.OAuth2.ClientCredentialsH\x00\x12I\n\x1atoken_fetch_retry_interval\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\x42\x07\xaa\x01\x04\x32\x02\x08\x01\x1a\xe6\x01\n\x11\x43lientCredentials\x12\x1a\n\tclient_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12[\n\rclient_secret\x18\x02 \x01(\x0b\x32:.envoy.extensions.transport_sockets.tls.v3.SdsSecretConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12X\n\tauth_type\x18\x03 \x01(\x0e\x32\x45.envoy.extensions.http.injected_credentials.oauth2.v3.OAuth2.AuthType\"0\n\x08\x41uthType\x12\x0e\n\nBASIC_AUTH\x10\x00\x12\x14\n\x10URL_ENCODED_BODY\x10\x01\x42\x10\n\tflow_type\x12\x03\xf8\x42\x01\x42\xc9\x01\nBio.envoyproxy.envoy.extensions.http.injected_credentials.oauth2.v3B\x0bOauth2ProtoP\x01Zdgithub.com/envoyproxy/go-control-plane/envoy/extensions/http/injected_credentials/oauth2/v3;oauth2v3\xba\x80\xc8\xd1\x06\x02\x10\x02\xd2\xc6\xa4\xe1\x06\x02\x08\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.http.injected_credentials.oauth2.v3.oauth2_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nBio.envoyproxy.envoy.extensions.http.injected_credentials.oauth2.v3B\013Oauth2ProtoP\001Zdgithub.com/envoyproxy/go-control-plane/envoy/extensions/http/injected_credentials/oauth2/v3;oauth2v3\272\200\310\321\006\002\020\002\322\306\244\341\006\002\010\001'
  _OAUTH2_CLIENTCREDENTIALS.fields_by_name['client_id']._options = None
  _OAUTH2_CLIENTCREDENTIALS.fields_by_name['client_id']._serialized_options = b'\372B\004r\002\020\001'
  _OAUTH2_CLIENTCREDENTIALS.fields_by_name['client_secret']._options = None
  _OAUTH2_CLIENTCREDENTIALS.fields_by_name['client_secret']._serialized_options = b'\372B\005\212\001\002\020\001'
  _OAUTH2.oneofs_by_name['flow_type']._options = None
  _OAUTH2.oneofs_by_name['flow_type']._serialized_options = b'\370B\001'
  _OAUTH2.fields_by_name['token_endpoint']._options = None
  _OAUTH2.fields_by_name['token_endpoint']._serialized_options = b'\372B\005\212\001\002\020\001'
  _OAUTH2.fields_by_name['token_fetch_retry_interval']._options = None
  _OAUTH2.fields_by_name['token_fetch_retry_interval']._serialized_options = b'\372B\007\252\001\0042\002\010\001'
  _globals['_OAUTH2']._serialized_start=338
  _globals['_OAUTH2']._serialized_end=913
  _globals['_OAUTH2_CLIENTCREDENTIALS']._serialized_start=615
  _globals['_OAUTH2_CLIENTCREDENTIALS']._serialized_end=845
  _globals['_OAUTH2_AUTHTYPE']._serialized_start=847
  _globals['_OAUTH2_AUTHTYPE']._serialized_end=895
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/config_change.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1egoogle/api/config_change.proto\x12\ngoogle.api\"\x97\x01\n\x0c\x43onfigChange\x12\x0f\n\x07\x65lement\x18\x01 \x01(\t\x12\x11\n\told_value\x18\x02 \x01(\t\x12\x11\n\tnew_value\x18\x03 \x01(\t\x12+\n\x0b\x63hange_type\x18\x04 \x01(\x0e\x32\x16.google.api.ChangeType\x12#\n\x07\x61\x64vices\x18\x05 \x03(\x0b\x32\x12.google.api.Advice\"\x1d\n\x06\x41\x64vice\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t*O\n\nChangeType\x12\x1b\n\x17\x43HANGE_TYPE_UNSPECIFIED\x10\x00\x12\t\n\x05\x41\x44\x44\x45\x44\x10\x01\x12\x0b\n\x07REMOVED\x10\x02\x12\x0c\n\x08MODIFIED\x10\x03\x42q\n\x0e\x63om.google.apiB\x11\x43onfigChangeProtoP\x01ZCgoogle.golang.org/genproto/googleapis/api/configchange;configchange\xa2\x02\x04GAPIb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.config_change_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\016com.google.apiB\021ConfigChangeProtoP\001ZCgoogle.golang.org/genproto/googleapis/api/configchange;configchange\242\002\004GAPI'
  _globals['_CHANGETYPE']._serialized_start=231
  _globals['_CHANGETYPE']._serialized_end=310
  _globals['_CONFIGCHANGE']._serialized_start=47
  _globals['_CONFIGCHANGE']._serialized_end=198
  _globals['_ADVICE']._serialized_start=200
  _globals['_ADVICE']._serialized_end=229
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/logging/v2/log_entry.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import monitored_resource_pb2 as google_dot_api_dot_monitored__resource__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.logging.type import http_request_pb2 as google_dot_logging_dot_type_dot_http__request__pb2
from google.logging.type import log_severity_pb2 as google_dot_logging_dot_type_dot_log__severity__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!google/logging/v2/log_entry.proto\x12\x11google.logging.v2\x1a\x1fgoogle/api/field_behavior.proto\x1a#google/api/monitored_resource.proto\x1a\x19google/api/resource.proto\x1a&google/logging/type/http_request.proto\x1a&google/logging/type/log_severity.proto\x1a\x19google/protobuf/any.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x83\x08\n\x08LogEntry\x12\x15\n\x08log_name\x18\x0c \x01(\tB\x03\xe0\x41\x02\x12\x34\n\x08resource\x18\x08 \x01(\x0b\x32\x1d.google.api.MonitoredResourceB\x03\xe0\x41\x02\x12-\n\rproto_payload\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x12\x16\n\x0ctext_payload\x18\x03 \x01(\tH\x00\x12/\n\x0cjson_payload\x18\x06 \x01(\x0b\x32\x17.google.protobuf.StructH\x00\x12\x32\n\ttimestamp\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x01\x12:\n\x11receive_timestamp\x18\x18 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03\x12\x37\n\x08severity\x18\n \x01(\x0e\x32 .google.logging.type.LogSeverityB\x03\xe0\x41\x01\x12\x16\n\tinsert_id\x18\x04 \x01(\tB\x03\xe0\x41\x01\x12;\n\x0chttp_request\x18\x07 \x01(\x0b\x32 .google.logging.type.HttpRequestB\x03\xe0\x41\x01\x12<\n\x06labels\x18\x0b \x03(\x0b\x32\'.google.logging.v2.LogEntry.LabelsEntryB\x03\xe0\x41\x01\x12<\n\toperation\x18\x0f \x01(\x0b\x32$.google.logging.v2.LogEntryOperationB\x03\xe0\x41\x01\x12\x12\n\x05trace\x18\x16 \x01(\tB\x03\xe0\x41\x01\x12\x14\n\x07span_id\x18\x1b \x01(\tB\x03\xe0\x41\x01\x12\x1a\n\rtrace_sampled\x18\x1e \x01(\x08\x42\x03\xe0\x41\x01\x12G\n\x0fsource_location\x18\x17 \x01(\x0b\x32).google.logging.v2.LogEntrySourceLocationB\x03\xe0\x41\x01\x12/\n\x05split\x18# \x01(\x0b\x32\x1b.google.logging.v2.LogSplitB\x03\xe0\x41\x01\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01:\xbd\x01\xea\x41\xb9\x01\n\x1alogging.googleapis.com/Log\x12\x1dprojects/{project}/logs/{log}\x12\'organizations/{organization}/logs/{log}\x12\x1b\x66olders/{folder}/logs/{log}\x12,billingAccounts/{billing_account}/logs/{log}\x1a\x08log_nameB\t\n\x07payload\"b\n\x11LogEntryOperation\x12\x0f\n\x02id\x18\x01 \x01(\tB\x03\xe0\x41\x01\x12\x15\n\x08producer\x18\x02 \x01(\tB\x03\xe0\x41\x01\x12\x12\n\x05\x66irst\x18\x03 \x01(\x08\x42\x03\xe0\x41\x01\x12\x11\n\x04last\x18\x04 \x01(\x08\x42\x03\xe0\x41\x01\"U\n\x16LogEntrySourceLocation\x12\x11\n\x04\x66ile\x18\x01 \x01(\tB\x03\xe0\x41\x01\x12\x11\n\x04line\x18\x02 \x01(\x03\x42\x03\xe0\x41\x01\x12\x15\n\x08\x66unction\x18\x03 \x01(\tB\x03\xe0\x41\x01\"<\n\x08LogSplit\x12\x0b\n\x03uid\x18\x01 \x01(\t\x12\r\n\x05index\x18\x02 \x01(\x05\x12\x14\n\x0ctotal_splits\x18\x03 \x01(\x05\x42\xb3\x01\n\x15\x63om.google.logging.v2B\rLogEntryProtoP\x01Z5cloud.google.com/go/logging/apiv2/loggingpb;loggingpb\xf8\x01\x01\xaa\x02\x17Google.Cloud.Logging.V2\xca\x02\x17Google\\Cloud\\Logging\\V2\xea\x02\x1aGoogle::Cloud::Logging::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.logging.v2.log_entry_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\025com.google.logging.v2B\rLogEntryProtoP\001Z5cloud.google.com/go/logging/apiv2/loggingpb;loggingpb\370\001\001\252\002\027Google.Cloud.Logging.V2\312\002\027Google\\Cloud\\Logging\\V2\352\002\032Google::Cloud::Logging::V2'
  _LOGENTRY_LABELSENTRY._options = None
  _LOGENTRY_LABELSENTRY._serialized_options = b'8\001'
  _LOGENTRY.fields_by_name['log_name']._options = None
  _LOGENTRY.fields_by_name['log_name']._serialized_options = b'\340A\002'
  _LOGENTRY.fields_by_name['resource']._options = None
  _LOGENTRY.fields_by_name['resource']._serialized_options = b'\340A\002'
  _LOGENTRY.fields_by_name['timestamp']._options = None
  _LOGENTRY.fields_by_name['timestamp']._serialized_options = b'\340A\001'
  _LOGENTRY.fields_by_name['receive_timestamp']._options = None
  _LOGENTRY.fields_by_name['receive_timestamp']._serialized_options = b'\340A\003'
  _LOGENTRY.fields_by_name['severity']._options = None
  _LOGENTRY.fields_by_name['severity']._serialized_options = b'\340A\001'
  _LOGENTRY.fields_by_name['insert_id']._options = None
  _LOGENTRY.fields_by_name['insert_id']._serialized_options = b'\340A\001'
  _LOGENTRY.fields_by_name['http_request']._options = None
  _LOGENTRY.fields_by_name['http_request']._serialized_options = b'\340A\001'
  _LOGENTRY.fields_by_name['labels']._options = None
  _LOGENTRY.fields_by_name['labels']._serialized_options = b'\340A\001'
  _LOGENTRY.fields_by_name['operation']._options = None
  _LOGENTRY.fields_by_name['operation']._serialized_options = b'\340A\001'
  _LOGENTRY.fields_by_name['trace']._options = None
  _LOGENTRY.fields_by_name['trace']._serialized_options = b'\340A\001'
  _LOGENTRY.fields_by_name['span_id']._options = None
  _LOGENTRY.fields_by_name['span_id']._serialized_options = b'\340A\001'
  _LOGENTRY.fields_by_name['trace_sampled']._options = None
  _LOGENTRY.fields_by_name['trace_sampled']._serialized_options = b'\340A\001'
  _LOGENTRY.fields_by_name['source_location']._options = None
  _LOGENTRY.fields_by_name['source_location']._serialized_options = b'\340A\001'
  _LOGENTRY.fields_by_name['split']._options = None
  _LOGENTRY.fields_by_name['split']._serialized_options = b'\340A\001'
  _LOGENTRY._options = None
  _LOGENTRY._serialized_options = b'\352A\271\001\n\032logging.googleapis.com/Log\022\035projects/{project}/logs/{log}\022\'organizations/{organization}/logs/{log}\022\033folders/{folder}/logs/{log}\022,billingAccounts/{billing_account}/logs/{log}\032\010log_name'
  _LOGENTRYOPERATION.fields_by_name['id']._options = None
  _LOGENTRYOPERATION.fields_by_name['id']._serialized_options = b'\340A\001'
  _LOGENTRYOPERATION.fields_by_name['producer']._options = None
  _LOGENTRYOPERATION.fields_by_name['producer']._serialized_options = b'\340A\001'
  _LOGENTRYOPERATION.fields_by_name['first']._options = None
  _LOGENTRYOPERATION.fields_by_name['first']._serialized_options = b'\340A\001'
  _LOGENTRYOPERATION.fields_by_name['last']._options = None
  _LOGENTRYOPERATION.fields_by_name['last']._serialized_options = b'\340A\001'
  _LOGENTRYSOURCELOCATION.fields_by_name['file']._options = None
  _LOGENTRYSOURCELOCATION.fields_by_name['file']._serialized_options = b'\340A\001'
  _LOGENTRYSOURCELOCATION.fields_by_name['line']._options = None
  _LOGENTRYSOURCELOCATION.fields_by_name['line']._serialized_options = b'\340A\001'
  _LOGENTRYSOURCELOCATION.fields_by_name['function']._options = None
  _LOGENTRYSOURCELOCATION.fields_by_name['function']._serialized_options = b'\340A\001'
  _globals['_LOGENTRY']._serialized_start=324
  _globals['_LOGENTRY']._serialized_end=1351
  _globals['_LOGENTRY_LABELSENTRY']._serialized_start=1103
  _globals['_LOGENTRY_LABELSENTRY']._serialized_end=1148
  _globals['_LOGENTRYOPERATION']._serialized_start=1353
  _globals['_LOGENTRYOPERATION']._serialized_end=1451
  _globals['_LOGENTRYSOURCELOCATION']._serialized_start=1453
  _globals['_LOGENTRYSOURCELOCATION']._serialized_end=1538
  _globals['_LOGSPLIT']._serialized_start=1540
  _globals['_LOGSPLIT']._serialized_end=1600
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: xds/type/matcher/v3/regex.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fxds/type/matcher/v3/regex.proto\x12\x13xds.type.matcher.v3\x1a\x17validate/validate.proto\"\x94\x01\n\x0cRegexMatcher\x12K\n\ngoogle_re2\x18\x01 \x01(\x0b\x32+.xds.type.matcher.v3.RegexMatcher.GoogleRE2B\x08\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00\x12\x16\n\x05regex\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x1a\x0b\n\tGoogleRE2B\x12\n\x0b\x65ngine_type\x12\x03\xf8\x42\x01\x42Z\n\x1e\x63om.github.xds.type.matcher.v3B\nRegexProtoP\x01Z*github.com/cncf/xds/go/xds/type/matcher/v3b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xds.type.matcher.v3.regex_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036com.github.xds.type.matcher.v3B\nRegexProtoP\001Z*github.com/cncf/xds/go/xds/type/matcher/v3'
  _REGEXMATCHER.oneofs_by_name['engine_type']._options = None
  _REGEXMATCHER.oneofs_by_name['engine_type']._serialized_options = b'\370B\001'
  _REGEXMATCHER.fields_by_name['google_re2']._options = None
  _REGEXMATCHER.fields_by_name['google_re2']._serialized_options = b'\372B\005\212\001\002\020\001'
  _REGEXMATCHER.fields_by_name['regex']._options = None
  _REGEXMATCHER.fields_by_name['regex']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_REGEXMATCHER']._serialized_start=82
  _globals['_REGEXMATCHER']._serialized_end=230
  _globals['_REGEXMATCHER_GOOGLERE2']._serialized_start=199
  _globals['_REGEXMATCHER_GOOGLERE2']._serialized_end=210
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/common/set_filter_state/v3/value.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import substitution_format_string_pb2 as envoy_dot_config_dot_core_dot_v3_dot_substitution__format__string__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?envoy/extensions/filters/common/set_filter_state/v3/value.proto\x12\x33\x65nvoy.extensions.filters.common.set_filter_state.v3\x1a\x35\x65nvoy/config/core/v3/substitution_format_string.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x85\x03\n\x10\x46ilterStateValue\x12\x1d\n\nobject_key\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00\x12\x13\n\x0b\x66\x61\x63tory_key\x18\x06 \x01(\t\x12G\n\rformat_string\x18\x02 \x01(\x0b\x32..envoy.config.core.v3.SubstitutionFormatStringH\x01\x12\x11\n\tread_only\x18\x03 \x01(\x08\x12v\n\x14shared_with_upstream\x18\x04 \x01(\x0e\x32X.envoy.extensions.filters.common.set_filter_state.v3.FilterStateValue.SharedWithUpstream\x12\x15\n\rskip_if_empty\x18\x05 \x01(\x08\"8\n\x12SharedWithUpstream\x12\x08\n\x04NONE\x10\x00\x12\x08\n\x04ONCE\x10\x01\x12\x0e\n\nTRANSITIVE\x10\x02\x42\n\n\x03key\x12\x03\xf8\x42\x01\x42\x0c\n\x05value\x12\x03\xf8\x42\x01\x42\xc8\x01\nAio.envoyproxy.envoy.extensions.filters.common.set_filter_state.v3B\nValueProtoP\x01Zmgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/common/set_filter_state/v3;set_filter_statev3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.common.set_filter_state.v3.value_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nAio.envoyproxy.envoy.extensions.filters.common.set_filter_state.v3B\nValueProtoP\001Zmgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/common/set_filter_state/v3;set_filter_statev3\272\200\310\321\006\002\020\002'
  _FILTERSTATEVALUE.oneofs_by_name['key']._options = None
  _FILTERSTATEVALUE.oneofs_by_name['key']._serialized_options = b'\370B\001'
  _FILTERSTATEVALUE.oneofs_by_name['value']._options = None
  _FILTERSTATEVALUE.oneofs_by_name['value']._serialized_options = b'\370B\001'
  _FILTERSTATEVALUE.fields_by_name['object_key']._options = None
  _FILTERSTATEVALUE.fields_by_name['object_key']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_FILTERSTATEVALUE']._serialized_start=232
  _globals['_FILTERSTATEVALUE']._serialized_end=621
  _globals['_FILTERSTATEVALUE_SHAREDWITHUPSTREAM']._serialized_start=539
  _globals['_FILTERSTATEVALUE_SHAREDWITHUPSTREAM']._serialized_end=595
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/listener/http_inspector/v3/http_inspector.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHenvoy/extensions/filters/listener/http_inspector/v3/http_inspector.proto\x12\x33\x65nvoy.extensions.filters.listener.http_inspector.v3\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"T\n\rHttpInspector:C\x9a\xc5\x88\x1e>\n<envoy.config.filter.listener.http_inspector.v2.HttpInspectorB\xce\x01\nAio.envoyproxy.envoy.extensions.filters.listener.http_inspector.v3B\x12HttpInspectorProtoP\x01Zkgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/listener/http_inspector/v3;http_inspectorv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.listener.http_inspector.v3.http_inspector_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nAio.envoyproxy.envoy.extensions.filters.listener.http_inspector.v3B\022HttpInspectorProtoP\001Zkgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/listener/http_inspector/v3;http_inspectorv3\272\200\310\321\006\002\020\002'
  _HTTPINSPECTOR._options = None
  _HTTPINSPECTOR._serialized_options = b'\232\305\210\036>\n<envoy.config.filter.listener.http_inspector.v2.HttpInspector'
  _globals['_HTTPINSPECTOR']._serialized_start=195
  _globals['_HTTPINSPECTOR']._serialized_end=279
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: xds/type/v3/typed_struct.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1exds/type/v3/typed_struct.proto\x12\x0bxds.type.v3\x1a\x1cgoogle/protobuf/struct.proto\"G\n\x0bTypedStruct\x12\x10\n\x08type_url\x18\x01 \x01(\t\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructBP\n\x16\x63om.github.xds.type.v3B\x10TypedStructProtoP\x01Z\"github.com/cncf/xds/go/xds/type/v3b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xds.type.v3.typed_struct_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026com.github.xds.type.v3B\020TypedStructProtoP\001Z\"github.com/cncf/xds/go/xds/type/v3'
  _globals['_TYPEDSTRUCT']._serialized_start=77
  _globals['_TYPEDSTRUCT']._serialized_end=148
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencensus/proto/stats/v1/stats.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%opencensus/proto/stats/v1/stats.proto\x12\x19opencensus.proto.stats.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"!\n\x03Tag\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\xa6\x01\n\x07Measure\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0c\n\x04unit\x18\x03 \x01(\t\x12\x35\n\x04type\x18\x04 \x01(\x0e\x32\'.opencensus.proto.stats.v1.Measure.Type\"3\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\t\n\x05INT64\x10\x01\x12\n\n\x06\x44OUBLE\x10\x02\"\xb9\x03\n\x04View\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x33\n\x07measure\x18\x03 \x01(\x0b\x32\".opencensus.proto.stats.v1.Measure\x12\x0f\n\x07\x63olumns\x18\x04 \x03(\t\x12H\n\x11\x63ount_aggregation\x18\x05 \x01(\x0b\x32+.opencensus.proto.stats.v1.CountAggregationH\x00\x12\x44\n\x0fsum_aggregation\x18\x06 \x01(\x0b\x32).opencensus.proto.stats.v1.SumAggregationH\x00\x12Q\n\x16last_value_aggregation\x18\x07 \x01(\x0b\x32/.opencensus.proto.stats.v1.LastValueAggregationH\x00\x12V\n\x18\x64istribution_aggregation\x18\x08 \x01(\x0b\x32\x32.opencensus.proto.stats.v1.DistributionAggregationH\x00\x42\r\n\x0b\x61ggregation\"\x12\n\x10\x43ountAggregation\"\x10\n\x0eSumAggregation\"\x16\n\x14LastValueAggregation\"0\n\x17\x44istributionAggregation\x12\x15\n\rbucket_bounds\x18\x01 \x03(\x01\"\xb1\x01\n\x0bMeasurement\x12,\n\x04tags\x18\x01 \x03(\x0b\x32\x1e.opencensus.proto.stats.v1.Tag\x12\x14\n\x0cmeasure_name\x18\x02 \x01(\t\x12\x16\n\x0c\x64ouble_value\x18\x03 \x01(\x01H\x00\x12\x13\n\tint_value\x18\x04 \x01(\x03H\x00\x12(\n\x04time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x07\n\x05valueB\x8c\x01\n\x1cio.opencensus.proto.stats.v1B\nStatsProtoP\x01ZBgithub.com/census-instrumentation/opencensus-proto/gen-go/stats/v1\xea\x02\x19OpenCensus.Proto.Stats.V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'opencensus.proto.stats.v1.stats_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\034io.opencensus.proto.stats.v1B\nStatsProtoP\001ZBgithub.com/census-instrumentation/opencensus-proto/gen-go/stats/v1\352\002\031OpenCensus.Proto.Stats.V1'
  _globals['_TAG']._serialized_start=101
  _globals['_TAG']._serialized_end=134
  _globals['_MEASURE']._serialized_start=137
  _globals['_MEASURE']._serialized_end=303
  _globals['_MEASURE_TYPE']._serialized_start=252
  _globals['_MEASURE_TYPE']._serialized_end=303
  _globals['_VIEW']._serialized_start=306
  _globals['_VIEW']._serialized_end=747
  _globals['_COUNTAGGREGATION']._serialized_start=749
  _globals['_COUNTAGGREGATION']._serialized_end=767
  _globals['_SUMAGGREGATION']._serialized_start=769
  _globals['_SUMAGGREGATION']._serialized_end=785
  _globals['_LASTVALUEAGGREGATION']._serialized_start=787
  _globals['_LASTVALUEAGGREGATION']._serialized_end=809
  _globals['_DISTRIBUTIONAGGREGATION']._serialized_start=811
  _globals['_DISTRIBUTIONAGGREGATION']._serialized_end=859
  _globals['_MEASUREMENT']._serialized_start=862
  _globals['_MEASUREMENT']._serialized_end=1039
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/serviceusage/v1beta1/resources.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import auth_pb2 as google_dot_api_dot_auth__pb2
from google.api import documentation_pb2 as google_dot_api_dot_documentation__pb2
from google.api import endpoint_pb2 as google_dot_api_dot_endpoint__pb2
from google.api import monitored_resource_pb2 as google_dot_api_dot_monitored__resource__pb2
from google.api import monitoring_pb2 as google_dot_api_dot_monitoring__pb2
from google.api import quota_pb2 as google_dot_api_dot_quota__pb2
from google.api import usage_pb2 as google_dot_api_dot_usage__pb2
from google.protobuf import api_pb2 as google_dot_protobuf_dot_api__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/google/api/serviceusage/v1beta1/resources.proto\x12\x1fgoogle.api.serviceusage.v1beta1\x1a\x15google/api/auth.proto\x1a\x1egoogle/api/documentation.proto\x1a\x19google/api/endpoint.proto\x1a#google/api/monitored_resource.proto\x1a\x1bgoogle/api/monitoring.proto\x1a\x16google/api/quota.proto\x1a\x16google/api/usage.proto\x1a\x19google/protobuf/api.proto\"\x9e\x01\n\x07Service\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06parent\x18\x05 \x01(\t\x12>\n\x06\x63onfig\x18\x02 \x01(\x0b\x32..google.api.serviceusage.v1beta1.ServiceConfig\x12\x35\n\x05state\x18\x04 \x01(\x0e\x32&.google.api.serviceusage.v1beta1.State\"\x95\x03\n\rServiceConfig\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\"\n\x04\x61pis\x18\x03 \x03(\x0b\x32\x14.google.protobuf.Api\x12\x30\n\rdocumentation\x18\x06 \x01(\x0b\x32\x19.google.api.Documentation\x12 \n\x05quota\x18\n \x01(\x0b\x32\x11.google.api.Quota\x12\x32\n\x0e\x61uthentication\x18\x0b \x01(\x0b\x32\x1a.google.api.Authentication\x12 \n\x05usage\x18\x0f \x01(\x0b\x32\x11.google.api.Usage\x12\'\n\tendpoints\x18\x12 \x03(\x0b\x32\x14.google.api.Endpoint\x12\x44\n\x13monitored_resources\x18\x19 \x03(\x0b\x32\'.google.api.MonitoredResourceDescriptor\x12*\n\nmonitoring\x18\x1c \x01(\x0b\x32\x16.google.api.Monitoring\"+\n\x11OperationMetadata\x12\x16\n\x0eresource_names\x18\x02 \x03(\t\"\x8a\x02\n\x13\x43onsumerQuotaMetric\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06metric\x18\x04 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12R\n\x15\x63onsumer_quota_limits\x18\x03 \x03(\x0b\x32\x33.google.api.serviceusage.v1beta1.ConsumerQuotaLimit\x12]\n descendant_consumer_quota_limits\x18\x06 \x03(\x0b\x32\x33.google.api.serviceusage.v1beta1.ConsumerQuotaLimit\x12\x0c\n\x04unit\x18\x05 \x01(\t\"\xd6\x01\n\x12\x43onsumerQuotaLimit\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06metric\x18\x08 \x01(\t\x12\x0c\n\x04unit\x18\x02 \x01(\t\x12\x12\n\nis_precise\x18\x03 \x01(\x08\x12\x1e\n\x16\x61llows_admin_overrides\x18\x07 \x01(\x08\x12\x43\n\rquota_buckets\x18\t \x03(\x0b\x32,.google.api.serviceusage.v1beta1.QuotaBucket\x12\x1b\n\x13supported_locations\x18\x0b \x03(\t\"\xf5\x03\n\x0bQuotaBucket\x12\x17\n\x0f\x65\x66\x66\x65\x63tive_limit\x18\x01 \x01(\x03\x12\x15\n\rdefault_limit\x18\x02 \x01(\x03\x12I\n\x11producer_override\x18\x03 \x01(\x0b\x32..google.api.serviceusage.v1beta1.QuotaOverride\x12I\n\x11\x63onsumer_override\x18\x04 \x01(\x0b\x32..google.api.serviceusage.v1beta1.QuotaOverride\x12\x46\n\x0e\x61\x64min_override\x18\x05 \x01(\x0b\x32..google.api.serviceusage.v1beta1.QuotaOverride\x12S\n\x15producer_quota_policy\x18\x07 \x01(\x0b\x32\x34.google.api.serviceusage.v1beta1.ProducerQuotaPolicy\x12P\n\ndimensions\x18\x06 \x03(\x0b\x32<.google.api.serviceusage.v1beta1.QuotaBucket.DimensionsEntry\x1a\x31\n\x0f\x44imensionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xfb\x01\n\rQuotaOverride\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x16\n\x0eoverride_value\x18\x02 \x01(\x03\x12R\n\ndimensions\x18\x03 \x03(\x0b\x32>.google.api.serviceusage.v1beta1.QuotaOverride.DimensionsEntry\x12\x0e\n\x06metric\x18\x04 \x01(\t\x12\x0c\n\x04unit\x18\x05 \x01(\t\x12\x1f\n\x17\x61\x64min_override_ancestor\x18\x06 \x01(\t\x1a\x31\n\x0f\x44imensionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"Y\n\x14OverrideInlineSource\x12\x41\n\toverrides\x18\x01 \x03(\x0b\x32..google.api.serviceusage.v1beta1.QuotaOverride\"\xf7\x01\n\x13ProducerQuotaPolicy\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0cpolicy_value\x18\x02 \x01(\x03\x12X\n\ndimensions\x18\x03 \x03(\x0b\x32\x44.google.api.serviceusage.v1beta1.ProducerQuotaPolicy.DimensionsEntry\x12\x0e\n\x06metric\x18\x04 \x01(\t\x12\x0c\n\x04unit\x18\x05 \x01(\t\x12\x11\n\tcontainer\x18\x06 \x01(\t\x1a\x31\n\x0f\x44imensionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf1\x01\n\x10\x41\x64minQuotaPolicy\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0cpolicy_value\x18\x02 \x01(\x03\x12U\n\ndimensions\x18\x03 \x03(\x0b\x32\x41.google.api.serviceusage.v1beta1.AdminQuotaPolicy.DimensionsEntry\x12\x0e\n\x06metric\x18\x04 \x01(\t\x12\x0c\n\x04unit\x18\x05 \x01(\t\x12\x11\n\tcontainer\x18\x06 \x01(\t\x1a\x31\n\x0f\x44imensionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"3\n\x0fServiceIdentity\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x11\n\tunique_id\x18\x02 \x01(\t*9\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x44ISABLED\x10\x01\x12\x0b\n\x07\x45NABLED\x10\x02*<\n\tQuotaView\x12\x1a\n\x16QUOTA_VIEW_UNSPECIFIED\x10\x00\x12\t\n\x05\x42\x41SIC\x10\x01\x12\x08\n\x04\x46ULL\x10\x02*~\n\x10QuotaSafetyCheck\x12\"\n\x1eQUOTA_SAFETY_CHECK_UNSPECIFIED\x10\x00\x12\x1e\n\x1aLIMIT_DECREASE_BELOW_USAGE\x10\x01\x12&\n\"LIMIT_DECREASE_PERCENTAGE_TOO_HIGH\x10\x02\x42\xed\x01\n#com.google.api.serviceusage.v1beta1B\x0eResourcesProtoP\x01ZKgoogle.golang.org/genproto/googleapis/api/serviceusage/v1beta1;serviceusage\xaa\x02\x1fGoogle.Api.ServiceUsage.V1Beta1\xca\x02\x1fGoogle\\Api\\ServiceUsage\\V1beta1\xea\x02\"Google::Api::ServiceUsage::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.serviceusage.v1beta1.resources_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#com.google.api.serviceusage.v1beta1B\016ResourcesProtoP\001ZKgoogle.golang.org/genproto/googleapis/api/serviceusage/v1beta1;serviceusage\252\002\037Google.Api.ServiceUsage.V1Beta1\312\002\037Google\\Api\\ServiceUsage\\V1beta1\352\002\"Google::Api::ServiceUsage::V1beta1'
  _QUOTABUCKET_DIMENSIONSENTRY._options = None
  _QUOTABUCKET_DIMENSIONSENTRY._serialized_options = b'8\001'
  _QUOTAOVERRIDE_DIMENSIONSENTRY._options = None
  _QUOTAOVERRIDE_DIMENSIONSENTRY._serialized_options = b'8\001'
  _PRODUCERQUOTAPOLICY_DIMENSIONSENTRY._options = None
  _PRODUCERQUOTAPOLICY_DIMENSIONSENTRY._serialized_options = b'8\001'
  _ADMINQUOTAPOLICY_DIMENSIONSENTRY._options = None
  _ADMINQUOTAPOLICY_DIMENSIONSENTRY._serialized_options = b'8\001'
  _globals['_STATE']._serialized_start=2803
  _globals['_STATE']._serialized_end=2860
  _globals['_QUOTAVIEW']._serialized_start=2862
  _globals['_QUOTAVIEW']._serialized_end=2922
  _globals['_QUOTASAFETYCHECK']._serialized_start=2924
  _globals['_QUOTASAFETYCHECK']._serialized_end=3050
  _globals['_SERVICE']._serialized_start=308
  _globals['_SERVICE']._serialized_end=466
  _globals['_SERVICECONFIG']._serialized_start=469
  _globals['_SERVICECONFIG']._serialized_end=874
  _globals['_OPERATIONMETADATA']._serialized_start=876
  _globals['_OPERATIONMETADATA']._serialized_end=919
  _globals['_CONSUMERQUOTAMETRIC']._serialized_start=922
  _globals['_CONSUMERQUOTAMETRIC']._serialized_end=1188
  _globals['_CONSUMERQUOTALIMIT']._serialized_start=1191
  _globals['_CONSUMERQUOTALIMIT']._serialized_end=1405
  _globals['_QUOTABUCKET']._serialized_start=1408
  _globals['_QUOTABUCKET']._serialized_end=1909
  _globals['_QUOTABUCKET_DIMENSIONSENTRY']._serialized_start=1860
  _globals['_QUOTABUCKET_DIMENSIONSENTRY']._serialized_end=1909
  _globals['_QUOTAOVERRIDE']._serialized_start=1912
  _globals['_QUOTAOVERRIDE']._serialized_end=2163
  _globals['_QUOTAOVERRIDE_DIMENSIONSENTRY']._serialized_start=1860
  _globals['_QUOTAOVERRIDE_DIMENSIONSENTRY']._serialized_end=1909
  _globals['_OVERRIDEINLINESOURCE']._serialized_start=2165
  _globals['_OVERRIDEINLINESOURCE']._serialized_end=2254
  _globals['_PRODUCERQUOTAPOLICY']._serialized_start=2257
  _globals['_PRODUCERQUOTAPOLICY']._serialized_end=2504
  _globals['_PRODUCERQUOTAPOLICY_DIMENSIONSENTRY']._serialized_start=1860
  _globals['_PRODUCERQUOTAPOLICY_DIMENSIONSENTRY']._serialized_end=1909
  _globals['_ADMINQUOTAPOLICY']._serialized_start=2507
  _globals['_ADMINQUOTAPOLICY']._serialized_end=2748
  _globals['_ADMINQUOTAPOLICY_DIMENSIONSENTRY']._serialized_start=1860
  _globals['_ADMINQUOTAPOLICY_DIMENSIONSENTRY']._serialized_end=1909
  _globals['_SERVICEIDENTITY']._serialized_start=2750
  _globals['_SERVICEIDENTITY']._serialized_end=2801
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/retry/previous_hosts/v2/previous_hosts.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9envoy/config/retry/previous_hosts/v2/previous_hosts.proto\x12$envoy.config.retry.previous_hosts.v2\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\"\x18\n\x16PreviousHostsPredicateB\xe5\x01\n2io.envoyproxy.envoy.config.retry.previous_hosts.v2B\x12PreviousHostsProtoP\x01Z\\github.com/envoyproxy/go-control-plane/envoy/config/retry/previous_hosts/v2;previous_hostsv2\xf2\x98\xfe\x8f\x05/\x12-envoy.extensions.retry.host.previous_hosts.v3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.retry.previous_hosts.v2.previous_hosts_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n2io.envoyproxy.envoy.config.retry.previous_hosts.v2B\022PreviousHostsProtoP\001Z\\github.com/envoyproxy/go-control-plane/envoy/config/retry/previous_hosts/v2;previous_hostsv2\362\230\376\217\005/\022-envoy.extensions.retry.host.previous_hosts.v3\272\200\310\321\006\002\020\002'
  _globals['_PREVIOUSHOSTSPREDICATE']._serialized_start=162
  _globals['_PREVIOUSHOSTSPREDICATE']._serialized_end=186
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/admin/v2alpha/metrics.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!envoy/admin/v2alpha/metrics.proto\x12\x13\x65nvoy.admin.v2alpha\x1a\x1dudpa/annotations/status.proto\"\x81\x01\n\x0cSimpleMetric\x12\x34\n\x04type\x18\x01 \x01(\x0e\x32&.envoy.admin.v2alpha.SimpleMetric.Type\x12\r\n\x05value\x18\x02 \x01(\x04\x12\x0c\n\x04name\x18\x03 \x01(\t\"\x1e\n\x04Type\x12\x0b\n\x07\x43OUNTER\x10\x00\x12\t\n\x05GAUGE\x10\x01\x42w\n!io.envoyproxy.envoy.admin.v2alphaB\x0cMetricsProtoP\x01Z:github.com/envoyproxy/go-control-plane/envoy/admin/v2alpha\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.admin.v2alpha.metrics_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!io.envoyproxy.envoy.admin.v2alphaB\014MetricsProtoP\001Z:github.com/envoyproxy/go-control-plane/envoy/admin/v2alpha\272\200\310\321\006\002\020\001'
  _globals['_SIMPLEMETRIC']._serialized_start=90
  _globals['_SIMPLEMETRIC']._serialized_end=219
  _globals['_SIMPLEMETRIC_TYPE']._serialized_start=189
  _globals['_SIMPLEMETRIC_TYPE']._serialized_end=219
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: xds/type/matcher/v3/http_inputs.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from xds.annotations.v3 import status_pb2 as xds_dot_annotations_dot_v3_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%xds/type/matcher/v3/http_inputs.proto\x12\x13xds.type.matcher.v3\x1a\x1fxds/annotations/v3/status.proto\"\x1d\n\x1bHttpAttributesCelMatchInputBg\n\x1e\x63om.github.xds.type.matcher.v3B\x0fHttpInputsProtoP\x01Z*github.com/cncf/xds/go/xds/type/matcher/v3\xd2\xc6\xa4\xe1\x06\x02\x08\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xds.type.matcher.v3.http_inputs_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036com.github.xds.type.matcher.v3B\017HttpInputsProtoP\001Z*github.com/cncf/xds/go/xds/type/matcher/v3\322\306\244\341\006\002\010\001'
  _globals['_HTTPATTRIBUTESCELMATCHINPUT']._serialized_start=95
  _globals['_HTTPATTRIBUTESCELMATCHINPUT']._serialized_end=124
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/endpoint/load_report.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import address_pb2 as envoy_dot_api_dot_v2_dot_core_dot_address__pb2
from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'envoy/api/v2/endpoint/load_report.proto\x12\x15\x65nvoy.api.v2.endpoint\x1a\x1f\x65nvoy/api/v2/core/address.proto\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xf6\x02\n\x15UpstreamLocalityStats\x12-\n\x08locality\x18\x01 \x01(\x0b\x32\x1b.envoy.api.v2.core.Locality\x12!\n\x19total_successful_requests\x18\x02 \x01(\x04\x12\"\n\x1atotal_requests_in_progress\x18\x03 \x01(\x04\x12\x1c\n\x14total_error_requests\x18\x04 \x01(\x04\x12\x1d\n\x15total_issued_requests\x18\x08 \x01(\x04\x12I\n\x11load_metric_stats\x18\x05 \x03(\x0b\x32..envoy.api.v2.endpoint.EndpointLoadMetricStats\x12M\n\x17upstream_endpoint_stats\x18\x07 \x03(\x0b\x32,.envoy.api.v2.endpoint.UpstreamEndpointStats\x12\x10\n\x08priority\x18\x06 \x01(\r\"\xbe\x02\n\x15UpstreamEndpointStats\x12+\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32\x1a.envoy.api.v2.core.Address\x12)\n\x08metadata\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12!\n\x19total_successful_requests\x18\x02 \x01(\x04\x12\"\n\x1atotal_requests_in_progress\x18\x03 \x01(\x04\x12\x1c\n\x14total_error_requests\x18\x04 \x01(\x04\x12\x1d\n\x15total_issued_requests\x18\x07 \x01(\x04\x12I\n\x11load_metric_stats\x18\x05 \x03(\x0b\x32..envoy.api.v2.endpoint.EndpointLoadMetricStats\"u\n\x17\x45ndpointLoadMetricStats\x12\x13\n\x0bmetric_name\x18\x01 \x01(\t\x12)\n!num_requests_finished_with_metric\x18\x02 \x01(\x04\x12\x1a\n\x12total_metric_value\x18\x03 \x01(\x01\"\x91\x03\n\x0c\x43lusterStats\x12\x1d\n\x0c\x63luster_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x1c\n\x14\x63luster_service_name\x18\x06 \x01(\t\x12W\n\x17upstream_locality_stats\x18\x02 \x03(\x0b\x32,.envoy.api.v2.endpoint.UpstreamLocalityStatsB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x12\x1e\n\x16total_dropped_requests\x18\x03 \x01(\x04\x12M\n\x10\x64ropped_requests\x18\x05 \x03(\x0b\x32\x33.envoy.api.v2.endpoint.ClusterStats.DroppedRequests\x12\x37\n\x14load_report_interval\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x1a\x43\n\x0f\x44roppedRequests\x12\x19\n\x08\x63\x61tegory\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x15\n\rdropped_count\x18\x02 \x01(\x04\x42\x9e\x01\n#io.envoyproxy.envoy.api.v2.endpointB\x0fLoadReportProtoP\x01Z<github.com/envoyproxy/go-control-plane/envoy/api/v2/endpoint\xf2\x98\xfe\x8f\x05\x1a\x12\x18\x65nvoy.config.endpoint.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.api.v2.endpoint.load_report_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#io.envoyproxy.envoy.api.v2.endpointB\017LoadReportProtoP\001Z<github.com/envoyproxy/go-control-plane/envoy/api/v2/endpoint\362\230\376\217\005\032\022\030envoy.config.endpoint.v3\272\200\310\321\006\002\020\001'
  _CLUSTERSTATS_DROPPEDREQUESTS.fields_by_name['category']._options = None
  _CLUSTERSTATS_DROPPEDREQUESTS.fields_by_name['category']._serialized_options = b'\372B\004r\002 \001'
  _CLUSTERSTATS.fields_by_name['cluster_name']._options = None
  _CLUSTERSTATS.fields_by_name['cluster_name']._serialized_options = b'\372B\004r\002 \001'
  _CLUSTERSTATS.fields_by_name['upstream_locality_stats']._options = None
  _CLUSTERSTATS.fields_by_name['upstream_locality_stats']._serialized_options = b'\372B\005\222\001\002\010\001'
  _globals['_UPSTREAMLOCALITYSTATS']._serialized_start=280
  _globals['_UPSTREAMLOCALITYSTATS']._serialized_end=654
  _globals['_UPSTREAMENDPOINTSTATS']._serialized_start=657
  _globals['_UPSTREAMENDPOINTSTATS']._serialized_end=975
  _globals['_ENDPOINTLOADMETRICSTATS']._serialized_start=977
  _globals['_ENDPOINTLOADMETRICSTATS']._serialized_end=1094
  _globals['_CLUSTERSTATS']._serialized_start=1097
  _globals['_CLUSTERSTATS']._serialized_end=1498
  _globals['_CLUSTERSTATS_DROPPEDREQUESTS']._serialized_start=1431
  _globals['_CLUSTERSTATS_DROPPEDREQUESTS']._serialized_end=1498
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/apikeys/v2/apikeys.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api.apikeys.v2 import resources_pb2 as google_dot_api_dot_apikeys_dot_v2_dot_resources__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.longrunning import operations_pb2 as google_dot_longrunning_dot_operations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#google/api/apikeys/v2/apikeys.proto\x12\x15google.api.apikeys.v2\x1a\x1cgoogle/api/annotations.proto\x1a%google/api/apikeys/v2/resources.proto\x1a\x17google/api/client.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a#google/longrunning/operations.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a google/protobuf/field_mask.proto\"\x84\x01\n\x10\x43reateKeyRequest\x12\x32\n\x06parent\x18\x01 \x01(\tB\"\xe0\x41\x02\xfa\x41\x1c\x12\x1a\x61pikeys.googleapis.com/Key\x12,\n\x03key\x18\x02 \x01(\x0b\x32\x1a.google.api.apikeys.v2.KeyB\x03\xe0\x41\x02\x12\x0e\n\x06key_id\x18\x03 \x01(\t\"\x91\x01\n\x0fListKeysRequest\x12\x32\n\x06parent\x18\x01 \x01(\tB\"\xe0\x41\x02\xfa\x41\x1c\x12\x1a\x61pikeys.googleapis.com/Key\x12\x16\n\tpage_size\x18\x02 \x01(\x05\x42\x03\xe0\x41\x01\x12\x17\n\npage_token\x18\x03 \x01(\tB\x03\xe0\x41\x01\x12\x19\n\x0cshow_deleted\x18\x06 \x01(\x08\x42\x03\xe0\x41\x01\"U\n\x10ListKeysResponse\x12(\n\x04keys\x18\x01 \x03(\x0b\x32\x1a.google.api.apikeys.v2.Key\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"A\n\rGetKeyRequest\x12\x30\n\x04name\x18\x01 \x01(\tB\"\xe0\x41\x02\xfa\x41\x1c\n\x1a\x61pikeys.googleapis.com/Key\"G\n\x13GetKeyStringRequest\x12\x30\n\x04name\x18\x01 \x01(\tB\"\xe0\x41\x02\xfa\x41\x1c\n\x1a\x61pikeys.googleapis.com/Key\"*\n\x14GetKeyStringResponse\x12\x12\n\nkey_string\x18\x01 \x01(\t\"q\n\x10UpdateKeyRequest\x12,\n\x03key\x18\x01 \x01(\x0b\x32\x1a.google.api.apikeys.v2.KeyB\x03\xe0\x41\x02\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"W\n\x10\x44\x65leteKeyRequest\x12\x30\n\x04name\x18\x01 \x01(\tB\"\xe0\x41\x02\xfa\x41\x1c\n\x1a\x61pikeys.googleapis.com/Key\x12\x11\n\x04\x65tag\x18\x02 \x01(\tB\x03\xe0\x41\x01\"F\n\x12UndeleteKeyRequest\x12\x30\n\x04name\x18\x01 \x01(\tB\"\xe0\x41\x02\xfa\x41\x1c\n\x1a\x61pikeys.googleapis.com/Key\"+\n\x10LookupKeyRequest\x12\x17\n\nkey_string\x18\x01 \x01(\tB\x03\xe0\x41\x02\"1\n\x11LookupKeyResponse\x12\x0e\n\x06parent\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t2\xbe\x0b\n\x07\x41piKeys\x12\xbd\x01\n\tCreateKey\x12\'.google.api.apikeys.v2.CreateKeyRequest\x1a\x1d.google.longrunning.Operation\"h\xca\x41\x1c\n\x03Key\x12\x15google.protobuf.Empty\xda\x41\x11parent,key,key_id\x82\xd3\xe4\x93\x02/\"(/v2/{parent=projects/*/locations/*}/keys:\x03key\x12\x96\x01\n\x08ListKeys\x12&.google.api.apikeys.v2.ListKeysRequest\x1a\'.google.api.apikeys.v2.ListKeysResponse\"9\xda\x41\x06parent\x82\xd3\xe4\x93\x02*\x12(/v2/{parent=projects/*/locations/*}/keys\x12\x83\x01\n\x06GetKey\x12$.google.api.apikeys.v2.GetKeyRequest\x1a\x1a.google.api.apikeys.v2.Key\"7\xda\x41\x04name\x82\xd3\xe4\x93\x02*\x12(/v2/{name=projects/*/locations/*/keys/*}\x12\xaa\x01\n\x0cGetKeyString\x12*.google.api.apikeys.v2.GetKeyStringRequest\x1a+.google.api.apikeys.v2.GetKeyStringResponse\"A\xda\x41\x04name\x82\xd3\xe4\x93\x02\x34\x12\x32/v2/{name=projects/*/locations/*/keys/*}/keyString\x12\xbf\x01\n\tUpdateKey\x12\'.google.api.apikeys.v2.UpdateKeyRequest\x1a\x1d.google.longrunning.Operation\"j\xca\x41\x1c\n\x03Key\x12\x15google.protobuf.Empty\xda\x41\x0fkey,update_mask\x82\xd3\xe4\x93\x02\x33\x32,/v2/{key.name=projects/*/locations/*/keys/*}:\x03key\x12\xab\x01\n\tDeleteKey\x12\'.google.api.apikeys.v2.DeleteKeyRequest\x1a\x1d.google.longrunning.Operation\"V\xca\x41\x1c\n\x03Key\x12\x15google.protobuf.Empty\xda\x41\x04name\x82\xd3\xe4\x93\x02**(/v2/{name=projects/*/locations/*/keys/*}\x12\xb4\x01\n\x0bUndeleteKey\x12).google.api.apikeys.v2.UndeleteKeyRequest\x1a\x1d.google.longrunning.Operation\"[\xca\x41\x1c\n\x03Key\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x36\"1/v2/{name=projects/*/locations/*/keys/*}:undelete:\x01*\x12z\n\tLookupKey\x12\'.google.api.apikeys.v2.LookupKeyRequest\x1a(.google.api.apikeys.v2.LookupKeyResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\x12\x12/v2/keys:lookupKey\x1a\x83\x01\xca\x41\x16\x61pikeys.googleapis.com\xd2\x41ghttps://www.googleapis.com/auth/cloud-platform,https://www.googleapis.com/auth/cloud-platform.read-onlyB\xb3\x01\n\x19\x63om.google.api.apikeys.v2B\x0c\x41piKeysProtoP\x01Z5cloud.google.com/go/apikeys/apiv2/apikeyspb;apikeyspb\xaa\x02\x17Google.Cloud.ApiKeys.V2\xca\x02\x17Google\\Cloud\\ApiKeys\\V2\xea\x02\x1aGoogle::Cloud::ApiKeys::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.apikeys.v2.apikeys_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.google.api.apikeys.v2B\014ApiKeysProtoP\001Z5cloud.google.com/go/apikeys/apiv2/apikeyspb;apikeyspb\252\002\027Google.Cloud.ApiKeys.V2\312\002\027Google\\Cloud\\ApiKeys\\V2\352\002\032Google::Cloud::ApiKeys::V2'
  _CREATEKEYREQUEST.fields_by_name['parent']._options = None
  _CREATEKEYREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002\372A\034\022\032apikeys.googleapis.com/Key'
  _CREATEKEYREQUEST.fields_by_name['key']._options = None
  _CREATEKEYREQUEST.fields_by_name['key']._serialized_options = b'\340A\002'
  _LISTKEYSREQUEST.fields_by_name['parent']._options = None
  _LISTKEYSREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002\372A\034\022\032apikeys.googleapis.com/Key'
  _LISTKEYSREQUEST.fields_by_name['page_size']._options = None
  _LISTKEYSREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTKEYSREQUEST.fields_by_name['page_token']._options = None
  _LISTKEYSREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\001'
  _LISTKEYSREQUEST.fields_by_name['show_deleted']._options = None
  _LISTKEYSREQUEST.fields_by_name['show_deleted']._serialized_options = b'\340A\001'
  _GETKEYREQUEST.fields_by_name['name']._options = None
  _GETKEYREQUEST.fields_by_name['name']._serialized_options = b'\340A\002\372A\034\n\032apikeys.googleapis.com/Key'
  _GETKEYSTRINGREQUEST.fields_by_name['name']._options = None
  _GETKEYSTRINGREQUEST.fields_by_name['name']._serialized_options = b'\340A\002\372A\034\n\032apikeys.googleapis.com/Key'
  _UPDATEKEYREQUEST.fields_by_name['key']._options = None
  _UPDATEKEYREQUEST.fields_by_name['key']._serialized_options = b'\340A\002'
  _DELETEKEYREQUEST.fields_by_name['name']._options = None
  _DELETEKEYREQUEST.fields_by_name['name']._serialized_options = b'\340A\002\372A\034\n\032apikeys.googleapis.com/Key'
  _DELETEKEYREQUEST.fields_by_name['etag']._options = None
  _DELETEKEYREQUEST.fields_by_name['etag']._serialized_options = b'\340A\001'
  _UNDELETEKEYREQUEST.fields_by_name['name']._options = None
  _UNDELETEKEYREQUEST.fields_by_name['name']._serialized_options = b'\340A\002\372A\034\n\032apikeys.googleapis.com/Key'
  _LOOKUPKEYREQUEST.fields_by_name['key_string']._options = None
  _LOOKUPKEYREQUEST.fields_by_name['key_string']._serialized_options = b'\340A\002'
  _APIKEYS._options = None
  _APIKEYS._serialized_options = b'\312A\026apikeys.googleapis.com\322Aghttps://www.googleapis.com/auth/cloud-platform,https://www.googleapis.com/auth/cloud-platform.read-only'
  _APIKEYS.methods_by_name['CreateKey']._options = None
  _APIKEYS.methods_by_name['CreateKey']._serialized_options = b'\312A\034\n\003Key\022\025google.protobuf.Empty\332A\021parent,key,key_id\202\323\344\223\002/\"(/v2/{parent=projects/*/locations/*}/keys:\003key'
  _APIKEYS.methods_by_name['ListKeys']._options = None
  _APIKEYS.methods_by_name['ListKeys']._serialized_options = b'\332A\006parent\202\323\344\223\002*\022(/v2/{parent=projects/*/locations/*}/keys'
  _APIKEYS.methods_by_name['GetKey']._options = None
  _APIKEYS.methods_by_name['GetKey']._serialized_options = b'\332A\004name\202\323\344\223\002*\022(/v2/{name=projects/*/locations/*/keys/*}'
  _APIKEYS.methods_by_name['GetKeyString']._options = None
  _APIKEYS.methods_by_name['GetKeyString']._serialized_options = b'\332A\004name\202\323\344\223\0024\0222/v2/{name=projects/*/locations/*/keys/*}/keyString'
  _APIKEYS.methods_by_name['UpdateKey']._options = None
  _APIKEYS.methods_by_name['UpdateKey']._serialized_options = b'\312A\034\n\003Key\022\025google.protobuf.Empty\332A\017key,update_mask\202\323\344\223\00232,/v2/{key.name=projects/*/locations/*/keys/*}:\003key'
  _APIKEYS.methods_by_name['DeleteKey']._options = None
  _APIKEYS.methods_by_name['DeleteKey']._serialized_options = b'\312A\034\n\003Key\022\025google.protobuf.Empty\332A\004name\202\323\344\223\002**(/v2/{name=projects/*/locations/*/keys/*}'
  _APIKEYS.methods_by_name['UndeleteKey']._options = None
  _APIKEYS.methods_by_name['UndeleteKey']._serialized_options = b'\312A\034\n\003Key\022\025google.protobuf.Empty\202\323\344\223\0026\"1/v2/{name=projects/*/locations/*/keys/*}:undelete:\001*'
  _APIKEYS.methods_by_name['LookupKey']._options = None
  _APIKEYS.methods_by_name['LookupKey']._serialized_options = b'\202\323\344\223\002\024\022\022/v2/keys:lookupKey'
  _globals['_CREATEKEYREQUEST']._serialized_start=317
  _globals['_CREATEKEYREQUEST']._serialized_end=449
  _globals['_LISTKEYSREQUEST']._serialized_start=452
  _globals['_LISTKEYSREQUEST']._serialized_end=597
  _globals['_LISTKEYSRESPONSE']._serialized_start=599
  _globals['_LISTKEYSRESPONSE']._serialized_end=684
  _globals['_GETKEYREQUEST']._serialized_start=686
  _globals['_GETKEYREQUEST']._serialized_end=751
  _globals['_GETKEYSTRINGREQUEST']._serialized_start=753
  _globals['_GETKEYSTRINGREQUEST']._serialized_end=824
  _globals['_GETKEYSTRINGRESPONSE']._serialized_start=826
  _globals['_GETKEYSTRINGRESPONSE']._serialized_end=868
  _globals['_UPDATEKEYREQUEST']._serialized_start=870
  _globals['_UPDATEKEYREQUEST']._serialized_end=983
  _globals['_DELETEKEYREQUEST']._serialized_start=985
  _globals['_DELETEKEYREQUEST']._serialized_end=1072
  _globals['_UNDELETEKEYREQUEST']._serialized_start=1074
  _globals['_UNDELETEKEYREQUEST']._serialized_end=1144
  _globals['_LOOKUPKEYREQUEST']._serialized_start=1146
  _globals['_LOOKUPKEYREQUEST']._serialized_end=1189
  _globals['_LOOKUPKEYRESPONSE']._serialized_start=1191
  _globals['_LOOKUPKEYRESPONSE']._serialized_end=1240
  _globals['_APIKEYS']._serialized_start=1243
  _globals['_APIKEYS']._serialized_end=2713
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/endpoint/v3/endpoint.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.endpoint.v3 import endpoint_components_pb2 as envoy_dot_config_dot_endpoint_dot_v3_dot_endpoint__components__pb2
from envoy.type.v3 import percent_pb2 as envoy_dot_type_dot_v3_dot_percent__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'envoy/config/endpoint/v3/endpoint.proto\x12\x18\x65nvoy.config.endpoint.v3\x1a\x32\x65nvoy/config/endpoint/v3/endpoint_components.proto\x1a\x1b\x65nvoy/type/v3/percent.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xb7\x07\n\x15\x43lusterLoadAssignment\x12\x1d\n\x0c\x63luster_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12@\n\tendpoints\x18\x02 \x03(\x0b\x32-.envoy.config.endpoint.v3.LocalityLbEndpoints\x12\\\n\x0fnamed_endpoints\x18\x05 \x03(\x0b\x32\x43.envoy.config.endpoint.v3.ClusterLoadAssignment.NamedEndpointsEntry\x12\x46\n\x06policy\x18\x04 \x01(\x0b\x32\x36.envoy.config.endpoint.v3.ClusterLoadAssignment.Policy\x1a\x90\x04\n\x06Policy\x12[\n\x0e\x64rop_overloads\x18\x02 \x03(\x0b\x32\x43.envoy.config.endpoint.v3.ClusterLoadAssignment.Policy.DropOverload\x12\x46\n\x17overprovisioning_factor\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02 \x00\x12\x41\n\x14\x65ndpoint_stale_after\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12 \n\x18weighted_priority_health\x18\x06 \x01(\x08\x1a\xa3\x01\n\x0c\x44ropOverload\x12\x19\n\x08\x63\x61tegory\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x39\n\x0f\x64rop_percentage\x18\x02 \x01(\x0b\x32 .envoy.type.v3.FractionalPercent:=\x9a\xc5\x88\x1e\x38\n6envoy.api.v2.ClusterLoadAssignment.Policy.DropOverload:0\x9a\xc5\x88\x1e+\n)envoy.api.v2.ClusterLoadAssignment.PolicyJ\x04\x08\x01\x10\x02J\x04\x08\x05\x10\x06R\x18\x64isable_overprovisioning\x1aY\n\x13NamedEndpointsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x31\n\x05value\x18\x02 \x01(\x0b\x32\".envoy.config.endpoint.v3.Endpoint:\x02\x38\x01:)\x9a\xc5\x88\x1e$\n\"envoy.api.v2.ClusterLoadAssignmentB\x8d\x01\n&io.envoyproxy.envoy.config.endpoint.v3B\rEndpointProtoP\x01ZJgithub.com/envoyproxy/go-control-plane/envoy/config/endpoint/v3;endpointv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.endpoint.v3.endpoint_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n&io.envoyproxy.envoy.config.endpoint.v3B\rEndpointProtoP\001ZJgithub.com/envoyproxy/go-control-plane/envoy/config/endpoint/v3;endpointv3\272\200\310\321\006\002\020\002'
  _CLUSTERLOADASSIGNMENT_POLICY_DROPOVERLOAD.fields_by_name['category']._options = None
  _CLUSTERLOADASSIGNMENT_POLICY_DROPOVERLOAD.fields_by_name['category']._serialized_options = b'\372B\004r\002\020\001'
  _CLUSTERLOADASSIGNMENT_POLICY_DROPOVERLOAD._options = None
  _CLUSTERLOADASSIGNMENT_POLICY_DROPOVERLOAD._serialized_options = b'\232\305\210\0368\n6envoy.api.v2.ClusterLoadAssignment.Policy.DropOverload'
  _CLUSTERLOADASSIGNMENT_POLICY.fields_by_name['overprovisioning_factor']._options = None
  _CLUSTERLOADASSIGNMENT_POLICY.fields_by_name['overprovisioning_factor']._serialized_options = b'\372B\004*\002 \000'
  _CLUSTERLOADASSIGNMENT_POLICY.fields_by_name['endpoint_stale_after']._options = None
  _CLUSTERLOADASSIGNMENT_POLICY.fields_by_name['endpoint_stale_after']._serialized_options = b'\372B\005\252\001\002*\000'
  _CLUSTERLOADASSIGNMENT_POLICY._options = None
  _CLUSTERLOADASSIGNMENT_POLICY._serialized_options = b'\232\305\210\036+\n)envoy.api.v2.ClusterLoadAssignment.Policy'
  _CLUSTERLOADASSIGNMENT_NAMEDENDPOINTSENTRY._options = None
  _CLUSTERLOADASSIGNMENT_NAMEDENDPOINTSENTRY._serialized_options = b'8\001'
  _CLUSTERLOADASSIGNMENT.fields_by_name['cluster_name']._options = None
  _CLUSTERLOADASSIGNMENT.fields_by_name['cluster_name']._serialized_options = b'\372B\004r\002\020\001'
  _CLUSTERLOADASSIGNMENT._options = None
  _CLUSTERLOADASSIGNMENT._serialized_options = b'\232\305\210\036$\n\"envoy.api.v2.ClusterLoadAssignment'
  _globals['_CLUSTERLOADASSIGNMENT']._serialized_start=306
  _globals['_CLUSTERLOADASSIGNMENT']._serialized_end=1257
  _globals['_CLUSTERLOADASSIGNMENT_POLICY']._serialized_start=595
  _globals['_CLUSTERLOADASSIGNMENT_POLICY']._serialized_end=1123
  _globals['_CLUSTERLOADASSIGNMENT_POLICY_DROPOVERLOAD']._serialized_start=872
  _globals['_CLUSTERLOADASSIGNMENT_POLICY_DROPOVERLOAD']._serialized_end=1035
  _globals['_CLUSTERLOADASSIGNMENT_NAMEDENDPOINTSENTRY']._serialized_start=1125
  _globals['_CLUSTERLOADASSIGNMENT_NAMEDENDPOINTSENTRY']._serialized_end=1214
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/clusters/dns/v3/dns_cluster.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import extension_pb2 as envoy_dot_config_dot_core_dot_v3_dot_extension__pb2
from envoy.extensions.clusters.common.dns.v3 import dns_pb2 as envoy_dot_extensions_dot_clusters_dot_common_dot_dns_dot_v3_dot_dns__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2envoy/extensions/clusters/dns/v3/dns_cluster.proto\x12 envoy.extensions.clusters.dns.v3\x1a$envoy/config/core/v3/extension.proto\x1a\x31\x65nvoy/extensions/clusters/common/dns/v3/dns.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xdc\x04\n\nDnsCluster\x12\x41\n\x10\x64ns_refresh_rate\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\x0c\xfa\x42\t\xaa\x01\x06*\x04\x10\xc0\x84=\x12Z\n\x18\x64ns_failure_refresh_rate\x18\x04 \x01(\x0b\x32\x38.envoy.extensions.clusters.dns.v3.DnsCluster.RefreshRate\x12\x17\n\x0frespect_dns_ttl\x18\x05 \x01(\x08\x12\x37\n\ndns_jitter\x18\x06 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02\x32\x00\x12M\n\x19typed_dns_resolver_config\x18\x07 \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfig\x12S\n\x11\x64ns_lookup_family\x18\x08 \x01(\x0e\x32\x38.envoy.extensions.clusters.common.dns.v3.DnsLookupFamily\x12(\n all_addresses_in_single_endpoint\x18\t \x01(\x08\x1a\x8e\x01\n\x0bRefreshRate\x12@\n\rbase_interval\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\x0e\xfa\x42\x0b\xaa\x01\x08\x08\x01*\x04\x10\xc0\x84=\x12=\n\x0cmax_interval\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x0c\xfa\x42\t\xaa\x01\x06*\x04\x10\xc0\x84=B\x9a\x01\n.io.envoyproxy.envoy.extensions.clusters.dns.v3B\x0f\x44nsClusterProtoP\x01ZMgithub.com/envoyproxy/go-control-plane/envoy/extensions/clusters/dns/v3;dnsv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.clusters.dns.v3.dns_cluster_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n.io.envoyproxy.envoy.extensions.clusters.dns.v3B\017DnsClusterProtoP\001ZMgithub.com/envoyproxy/go-control-plane/envoy/extensions/clusters/dns/v3;dnsv3\272\200\310\321\006\002\020\002'
  _DNSCLUSTER_REFRESHRATE.fields_by_name['base_interval']._options = None
  _DNSCLUSTER_REFRESHRATE.fields_by_name['base_interval']._serialized_options = b'\372B\013\252\001\010\010\001*\004\020\300\204='
  _DNSCLUSTER_REFRESHRATE.fields_by_name['max_interval']._options = None
  _DNSCLUSTER_REFRESHRATE.fields_by_name['max_interval']._serialized_options = b'\372B\t\252\001\006*\004\020\300\204='
  _DNSCLUSTER.fields_by_name['dns_refresh_rate']._options = None
  _DNSCLUSTER.fields_by_name['dns_refresh_rate']._serialized_options = b'\372B\t\252\001\006*\004\020\300\204='
  _DNSCLUSTER.fields_by_name['dns_jitter']._options = None
  _DNSCLUSTER.fields_by_name['dns_jitter']._serialized_options = b'\372B\005\252\001\0022\000'
  _globals['_DNSCLUSTER']._serialized_start=266
  _globals['_DNSCLUSTER']._serialized_end=870
  _globals['_DNSCLUSTER_REFRESHRATE']._serialized_start=728
  _globals['_DNSCLUSTER_REFRESHRATE']._serialized_end=870
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/basic_auth/v3/basic_auth.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from udpa.annotations import sensitive_pb2 as udpa_dot_annotations_dot_sensitive__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<envoy/extensions/filters/http/basic_auth/v3/basic_auth.proto\x12+envoy.extensions.filters.http.basic_auth.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a udpa/annotations/sensitive.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x9e\x01\n\tBasicAuth\x12\x37\n\x05users\x18\x01 \x01(\x0b\x32 .envoy.config.core.v3.DataSourceB\x06\xb8\xb7\x8b\xa4\x02\x01\x12,\n\x17\x66orward_username_header\x18\x02 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x01\xc8\x01\x00\x12*\n\x15\x61uthentication_header\x18\x03 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x01\xc8\x01\x00\"T\n\x11\x42\x61sicAuthPerRoute\x12?\n\x05users\x18\x01 \x01(\x0b\x32 .envoy.config.core.v3.DataSourceB\x0e\xfa\x42\x05\x8a\x01\x02\x10\x01\xb8\xb7\x8b\xa4\x02\x01\x42\xb6\x01\n9io.envoyproxy.envoy.extensions.filters.http.basic_auth.v3B\x0e\x42\x61sicAuthProtoP\x01Z_github.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/basic_auth/v3;basic_authv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.basic_auth.v3.basic_auth_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n9io.envoyproxy.envoy.extensions.filters.http.basic_auth.v3B\016BasicAuthProtoP\001Z_github.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/basic_auth/v3;basic_authv3\272\200\310\321\006\002\020\002'
  _BASICAUTH.fields_by_name['users']._options = None
  _BASICAUTH.fields_by_name['users']._serialized_options = b'\270\267\213\244\002\001'
  _BASICAUTH.fields_by_name['forward_username_header']._options = None
  _BASICAUTH.fields_by_name['forward_username_header']._serialized_options = b'\372B\010r\006\300\001\001\310\001\000'
  _BASICAUTH.fields_by_name['authentication_header']._options = None
  _BASICAUTH.fields_by_name['authentication_header']._serialized_options = b'\372B\010r\006\300\001\001\310\001\000'
  _BASICAUTHPERROUTE.fields_by_name['users']._options = None
  _BASICAUTHPERROUTE.fields_by_name['users']._serialized_options = b'\372B\005\212\001\002\020\001\270\267\213\244\002\001'
  _globals['_BASICAUTH']._serialized_start=233
  _globals['_BASICAUTH']._serialized_end=391
  _globals['_BASICAUTHPERROUTE']._serialized_start=393
  _globals['_BASICAUTHPERROUTE']._serialized_end=477
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/data/core/v2alpha/health_check_event.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import address_pb2 as envoy_dot_api_dot_v2_dot_core_dot_address__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0envoy/data/core/v2alpha/health_check_event.proto\x12\x17\x65nvoy.data.core.v2alpha\x1a\x1f\x65nvoy/api/v2/core/address.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x81\x05\n\x10HealthCheckEvent\x12Q\n\x13health_checker_type\x18\x01 \x01(\x0e\x32*.envoy.data.core.v2alpha.HealthCheckerTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12(\n\x04host\x18\x02 \x01(\x0b\x32\x1a.envoy.api.v2.core.Address\x12\x1d\n\x0c\x63luster_name\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12S\n\x15\x65ject_unhealthy_event\x18\x04 \x01(\x0b\x32\x32.envoy.data.core.v2alpha.HealthCheckEjectUnhealthyH\x00\x12K\n\x11\x61\x64\x64_healthy_event\x18\x05 \x01(\x0b\x32..envoy.data.core.v2alpha.HealthCheckAddHealthyH\x00\x12Q\n\x1ahealth_check_failure_event\x18\x07 \x01(\x0b\x32+.envoy.data.core.v2alpha.HealthCheckFailureH\x00\x12M\n\x15\x64\x65graded_healthy_host\x18\x08 \x01(\x0b\x32,.envoy.data.core.v2alpha.DegradedHealthyHostH\x00\x12P\n\x17no_longer_degraded_host\x18\t \x01(\x0b\x32-.envoy.data.core.v2alpha.NoLongerDegradedHostH\x00\x12-\n\ttimestamp\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x0c\n\x05\x65vent\x12\x03\xf8\x42\x01\"l\n\x19HealthCheckEjectUnhealthy\x12O\n\x0c\x66\x61ilure_type\x18\x01 \x01(\x0e\x32/.envoy.data.core.v2alpha.HealthCheckFailureTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\",\n\x15HealthCheckAddHealthy\x12\x13\n\x0b\x66irst_check\x18\x01 \x01(\x08\"z\n\x12HealthCheckFailure\x12O\n\x0c\x66\x61ilure_type\x18\x01 \x01(\x0e\x32/.envoy.data.core.v2alpha.HealthCheckFailureTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x13\n\x0b\x66irst_check\x18\x02 \x01(\x08\"\x15\n\x13\x44\x65gradedHealthyHost\"\x16\n\x14NoLongerDegradedHost*>\n\x16HealthCheckFailureType\x12\n\n\x06\x41\x43TIVE\x10\x00\x12\x0b\n\x07PASSIVE\x10\x01\x12\x0b\n\x07NETWORK\x10\x02*;\n\x11HealthCheckerType\x12\x08\n\x04HTTP\x10\x00\x12\x07\n\x03TCP\x10\x01\x12\x08\n\x04GRPC\x10\x02\x12\t\n\x05REDIS\x10\x03\x42\x88\x01\n%io.envoyproxy.envoy.data.core.v2alphaB\x15HealthCheckEventProtoP\x01Z>github.com/envoyproxy/go-control-plane/envoy/data/core/v2alpha\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.data.core.v2alpha.health_check_event_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%io.envoyproxy.envoy.data.core.v2alphaB\025HealthCheckEventProtoP\001Z>github.com/envoyproxy/go-control-plane/envoy/data/core/v2alpha\272\200\310\321\006\002\020\001'
  _HEALTHCHECKEVENT.oneofs_by_name['event']._options = None
  _HEALTHCHECKEVENT.oneofs_by_name['event']._serialized_options = b'\370B\001'
  _HEALTHCHECKEVENT.fields_by_name['health_checker_type']._options = None
  _HEALTHCHECKEVENT.fields_by_name['health_checker_type']._serialized_options = b'\372B\005\202\001\002\020\001'
  _HEALTHCHECKEVENT.fields_by_name['cluster_name']._options = None
  _HEALTHCHECKEVENT.fields_by_name['cluster_name']._serialized_options = b'\372B\004r\002 \001'
  _HEALTHCHECKEJECTUNHEALTHY.fields_by_name['failure_type']._options = None
  _HEALTHCHECKEJECTUNHEALTHY.fields_by_name['failure_type']._serialized_options = b'\372B\005\202\001\002\020\001'
  _HEALTHCHECKFAILURE.fields_by_name['failure_type']._options = None
  _HEALTHCHECKFAILURE.fields_by_name['failure_type']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_HEALTHCHECKFAILURETYPE']._serialized_start=1170
  _globals['_HEALTHCHECKFAILURETYPE']._serialized_end=1232
  _globals['_HEALTHCHECKERTYPE']._serialized_start=1234
  _globals['_HEALTHCHECKERTYPE']._serialized_end=1293
  _globals['_HEALTHCHECKEVENT']._serialized_start=200
  _globals['_HEALTHCHECKEVENT']._serialized_end=841
  _globals['_HEALTHCHECKEJECTUNHEALTHY']._serialized_start=843
  _globals['_HEALTHCHECKEJECTUNHEALTHY']._serialized_end=951
  _globals['_HEALTHCHECKADDHEALTHY']._serialized_start=953
  _globals['_HEALTHCHECKADDHEALTHY']._serialized_end=997
  _globals['_HEALTHCHECKFAILURE']._serialized_start=999
  _globals['_HEALTHCHECKFAILURE']._serialized_end=1121
  _globals['_DEGRADEDHEALTHYHOST']._serialized_start=1123
  _globals['_DEGRADEDHEALTHYHOST']._serialized_end=1144
  _globals['_NOLONGERDEGRADEDHOST']._serialized_start=1146
  _globals['_NOLONGERDEGRADEDHOST']._serialized_end=1168
# @@protoc_insertion_point(module_scope)
